import React, { useEffect, useState } from "react";
import axios from "axios";
import "./MyProfile.css";

const MyProfile = () => {
  const [personInfo, setPersonInfo] = useState(null);
  const [degrees, setDegrees] = useState([]);
  const [addresses, setAddresses] = useState([]);
  const [contacts, setContacts] = useState([]);
  const [involvements, setInvolvements] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState("");
  const [isEditing, setIsEditing] = useState(false);

  useEffect(() => {
    const fetchProfileData = async () => {
      const token = localStorage.getItem("jwtToken");

      if (!token) {
        setError("User is not authenticated!");
        setLoading(false);
        return;
      }

      const peopleId = localStorage.getItem("peopleId");

      if (!peopleId) {
        setError("No people ID found!");
        setLoading(false);
        return;
      }

      try {
        const response = await axios.get(
          `${process.env.REACT_APP_API_URL}/person/fullInfo/${peopleId}`,
          {
            headers: {
              Authorization: `Bearer ${token}`,
            },
          }
        );

        const { personInfo, degrees, addresses, contacts, involvements } =
          response.data.person;

        setPersonInfo(personInfo);
        setDegrees(degrees);
        setAddresses(addresses);
        setContacts(contacts);
        setInvolvements(involvements);

        setLoading(false);
      } catch (err) {
        setError("Failed to fetch profile data.");
        setLoading(false);
        console.error(err);
      }
    };

    fetchProfileData();
  }, []);

  const handleSave = async () => {
    const peopleId = localStorage.getItem("peopleId");
    const token = localStorage.getItem("jwtToken");

    if (!token) {
      setError("User is not authenticated!");
      setLoading(false);
      return;
    }

    if (!peopleId) {
      setError("No people ID found for this person!");
      setLoading(false);
      return;
    }

    try {
      const updatedDetails = {
        personInfo,
        degrees,
        addresses,
        contacts,
        involvements,
      };

      await axios.put(
        `${process.env.REACT_APP_API_URL}/person/update/${peopleId}`,
        updatedDetails,
        {
          headers: {
            Authorization: `Bearer ${token}`,
          },
        }
      );

      setIsEditing(false);
      alert("Profile updated successfully!");
    } catch (err) {
      alert("Failed to update profile.");
      console.error(err);
    }
  };

  const addNewItem = (setter, template) => {
    setter((prev) => [...prev, template]);
  };

  const deleteItem = (setter, index) => {
    setter((prev) => prev.filter((_, i) => i !== index));
  };

  if (loading) return <p>Loading your profile...</p>;
  if (error) return <p>{error}</p>;

  return (
    <div className="my-profile">
      <h1>My Profile</h1>

      {/* Personal Information */}
      <section className="section">
        <h2>Personal Information</h2>
        {Object.entries(personInfo || {}).map(([key, value]) =>
          key.toLowerCase().includes("id") ? null : (
            <p key={key}>
              <strong>{key.replace(/([A-Z])/g, " $1")}:</strong>{" "}
              {isEditing ? (
                <input
                  type="text"
                  value={value || ""}
                  onChange={(e) =>
                    setPersonInfo((prev) => ({
                      ...prev,
                      [key]: e.target.value,
                    }))
                  }
                />
              ) : (
                value || "N/A"
              )}
            </p>
          )
        )}
      </section>

      {/* Degree Information */}
      <section className="section">
        <h2>Degree Information</h2>
        {degrees.map((degree, index) => (
          <div key={index} className="listItem">
            {Object.entries(degree).map(([key, value]) =>
              key.toLowerCase().includes("id") ? null : (
                <p key={key}>
                  <strong>{key.replace(/([A-Z])/g, " $1")}:</strong>{" "}
                  {isEditing ? (
                    <input
                      type="text"
                      value={value || ""}
                      onChange={(e) =>
                        setDegrees((prev) =>
                          prev.map((deg, i) =>
                            i === index
                              ? { ...deg, [key]: e.target.value }
                              : deg
                          )
                        )
                      }
                    />
                  ) : (
                    value || "N/A"
                  )}
                </p>
              )
            )}
            {isEditing && (
              <button
                className="removeButton"
                onClick={() => deleteItem(setDegrees, index)}
              >
                Remove
              </button>
            )}
          </div>
        ))}
        {isEditing && (
          <button
            className="addButton"
            onClick={() =>
              addNewItem(setDegrees, {
                degreeType: "",
                degreeDepartment: "",
                degreeCollege: "",
                degreeYear: "",
                degreeDescription: "",
              })
            }
          >
            Add Degree
          </button>
        )}
      </section>

      {/* Address Information */}
      <section className="details">
        <h2>Address Information</h2>
        {addresses.map((address, index) => (
          <div key={index} className="listItem">
            {Object.entries(address).map(([key, value]) =>
              key.toLowerCase().includes("id") ? null : (
                <p key={key}>
                  <strong>{key.replace(/([A-Z])/g, " $1")}:</strong>{" "}
                  {isEditing ? (
                    <input
                      type="text"
                      value={value || ""}
                      onChange={(e) =>
                        setAddresses((prev) =>
                          prev.map((addr, i) =>
                            i === index
                              ? { ...addr, [key]: e.target.value }
                              : addr
                          )
                        )
                      }
                    />
                  ) : (
                    value || "N/A"
                  )}
                </p>
              )
            )}
            {isEditing && (
              <button
                className="removeButton"
                onClick={() => deleteItem(setAddresses, index)}
              >
                Remove
              </button>
            )}
          </div>
        ))}
        {isEditing && (
          <button
            className="addButton"
            onClick={() =>
              addNewItem(setAddresses, {
                address1: "",
                address2: "",
                city: "",
                state: "",
                country: "",
                zipCode: "",
                preferredAddress: false,
              })
            }
          >
            Add Address
          </button>
        )}
      </section>

      {/* Contact Information */}
      <section className="details">
        <h2>Contact Information</h2>
        {contacts.map((contact, index) => (
          <div key={index} className="listItem">
            {Object.entries(contact).map(([key, value]) =>
              key.toLowerCase().includes("id") ? null : (
                <p key={key}>
                  <strong>{key.replace(/([A-Z])/g, " $1")}:</strong>{" "}
                  {isEditing ? (
                    <input
                      type="text"
                      value={value || ""}
                      onChange={(e) =>
                        setContacts((prev) =>
                          prev.map((con, i) =>
                            i === index
                              ? { ...con, [key]: e.target.value }
                              : con
                          )
                        )
                      }
                    />
                  ) : (
                    value || "N/A"
                  )}
                </p>
              )
            )}
            {isEditing && (
              <button
                className="removeButton"
                onClick={() => deleteItem(setContacts, index)}
              >
                Remove
              </button>
            )}
          </div>
        ))}
        {isEditing && (
          <button
            className="addButton"
            onClick={() =>
              addNewItem(setContacts, {
                contactType: "",
                contactNumber: "",
                preferredContact: false,
              })
            }
          >
            Add Contact
          </button>
        )}
      </section>

      {/* Involvement Information */}
      <section className="details">
        <h2>Involvement Information</h2>
        {involvements.map((involvement, index) => (
          <div key={index} className="listItem">
            <p>
              {isEditing ? (
                <input
                  type="text"
                  value={involvement || ""}
                  onChange={(e) =>
                    setInvolvements((prev) =>
                      prev.map((inv, i) => (i === index ? e.target.value : inv))
                    )
                  }
                />
              ) : (
                involvement || "N/A"
              )}
            </p>
            {isEditing && (
              <button
                className="removeButton"
                onClick={() => deleteItem(setInvolvements, index)}
              >
                Remove
              </button>
            )}
          </div>
        ))}
        {isEditing && (
          <button
            className="addButton"
            onClick={() => addNewItem(setInvolvements, "")}
          >
            Add Involvement
          </button>
        )}
      </section>

      {/* Actions */}
      <div className="button-container">
        {!isEditing ? (
          <button className="editButton" onClick={() => setIsEditing(true)}>
            Edit
          </button>
        ) : (
          <button className="saveButton" onClick={handleSave}>
            Save
          </button>
        )}
      </div>
    </div>
  );
};

export default MyProfile;
